import request from '@/utils/request'

//开票申请数据
export function applyDetail(data){
  return request({
    url: '/adsMatHyxtInvoiceD/applyDetail',
    method: 'post',
    data:data
  })
}
//下载模版
export function downloadTemplate(){
  return request({
    url: '/adsMatHyxtInvoiceD/downloadTemplate',
    method: 'post',
    headers: {
      "Content-Type": "application/json",
      charset: "utf-8",
    },
    responseType: "blob",
  })
}
//导入模版
export function invoiceImport(data){
  return request({
    url: '/adsMatHyxtInvoiceD/invoiceImport',
    method: 'post',
    data:data,
  })
}
//保存
export function applySave(data,id){
  return request({
    url: '/adsMatHyxtInvoiceD/applySave',
    method: 'post',
    data:{
      id:id,
      list:data,
    },
  })
}
//开票申请提交审核
export function commitAudit(data){
  return request({
    url: '/adsMatHyxtInvoiceD/commitAudit',
    method: 'post',
    data:data,
  })
}
//开票申请单批量删除
export function applyDelete(data){
  return request({
    url: '/adsMatHyxtInvoiceD/deleteApply',
    method: 'post',
    data:data,
  })
}

//开票申请审核人员
export function getUserList(data){
  return request({
    url: '/system/user/getUserList',
    method: 'get',
    data:data,
  })
}
//撤回
export function withdraw(data){
  return request({
    url: '/adsMatHyxtInvoiceD/withdraw',
    method: 'post',
    data:data,
  })
}
//开票申请导出
export function applyInvoiceExport(data){
  return request({
    url: '/adsMatHyxtInvoiceD/applyInvoiceExport',
    method: 'post',
    data:data,
    responseType: "blob",
  })
}
//待办任务详情数据
export function applyAuditDetail(data){
  return request({
    url: '/adsMatHyxtInvoiceD/applyAuditDetail',
    method: 'post',
    data:data,
  })
}
//文件上传
export function uploadFile(data){
  return request({
    url: '/adsMatHyxtInvoiceD/invoiceOcrScan',
    method: 'post',
    data:data,
    headers: {
      "Content-Type": "application/json",
      charset: "utf-8",
    },
    // responseType: "blob",
  })
}

//文件上传保存
export function invoiceSave(data){
  return request({
    url: '/adsMatHyxtInvoiceFileD/invoiceSave',
    method: 'post',
    data:data,
  })
}

//文件凭证
export function invoiceSaveE(data){
  return request({
    url: '/adsMatHyxtInvoiceD/invoiceSave',
    method: 'post',
    data:data,
  })
}
//文件凭证保存
export function invoiceCodeSave(data){
  return request({
    url: '/adsMatHyxtInvoiceD/codeSave',
    method: 'post',
    data:data,
  })
}
//可用预算金额保存
export function validBudgetAmountSave(data){
  return request({
    url: '/adsMatHyxtInvoiceD/validBudgetAmountSave',
    method: 'post',
    data:data,
  })
}
//可用预算金额批次
export function validBudgetAmountBatchSave(data){
  return request({
    url: '/adsMatHyxtInvoiceD/validBudgetAmountBatchSave',
    method: 'post',
    data:data,
  })
}
//审核
export function Invoiceaudit(data){
  return request({
    url: '/adsMatHyxtInvoiceD/audit',
    method: 'post',
    data:data,
  })
}
//发票回显
export function invoiceDetail(data){
  return request({
    url: '/adsMatHyxtInvoiceD/invoiceUploadDetail',
    method: 'post',
    data:data,
  })
}
//接受报账
export function applyUpdate(data){
  return request({
    url: '/adsMatHyxtInvoiceD/applyUpdate',
    method: 'post',
    data:data,
  })
}

//提交权限表数据
export function userApplyPermissionPage(data){
  return request({
    url: '/userApplyPermissionD/page',
    method: 'post',
    data:data,
  })
}
//提交权限开关修改
export function updateApplyPermission(data){
  return request({
    url: '/userApplyPermissionD/updateApplyPermission',
    method: 'post',
    data:data,
  })
}

//代办任务批量审核
export function batchAudit(data){
  return request({
    url: '/adsMatHyxtInvoiceD/batchAudit',
    method: 'post',
    data:data,
  })
}


export function invoiceListD(data){
  return request({
    url: '/adsMatHyxtInvoiceFileD/invoicePage',
    method: 'post',
    data:data,
  })
}

export function invoiceDelete(data){
  return request({
    url: '/adsMatHyxtInvoiceFileD/invoiceDelete',
    method: 'post',
    data:data,
  })
}

export function invoiceDqueryPagee(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/queryPage',
    method: 'post',
    params:{
      pageSize:data.pageSize,
      pageNo:data.pageNo,
    },
    data:data,
  })
}

export function downloadTemplateD(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/downloadTemplate',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function contractImport(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/contractImport',
    method: 'post',
    data:data,
    headers:{
      'content-type':'multipart/form-data'
    }
  })
}
export function queryList(data){
  return request({
    url: '/adsMatHyxtStampTaxItemD/queryList',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxContractDL(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/update',
    method: 'post',
    data:data,
  })
}
export function deleteadsMatHyxtStampTaxContractD(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/delete',
    method: 'post',
    data:data,
  })
}
export function queryPageNo(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/queryPage',
    method: 'post',
    data:data,
    params:{
      pageSize:data.pageSize,
      pageNo:data.pageNo,
    },
  })
}
export function downloadTemplateM(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/downloadTemplate',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function invoiceImportP(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/invoiceImport',
    method: 'post',
    data:data,
    headers:{
      'content-type':'multipart/form-data'
    }
  })
}
export function adsMatHyxtStampTaxInvoiceDelc(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/delete',
    method: 'post',
    data:data,
  })
}
export function stampTaxBase(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/stampTaxBase',
    method: 'post',
    data:data,
  })
}
export function stampTaxComputeBill(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/stampTaxComputeBill',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxComputeDqueryPage(data,list){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/queryPage',
    method: 'post',
    params:data,
    data:list
  })
}

export function adsMatHyxtStampTaxWarningD(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/delWarning',
    method: 'post',
    data:data,
  })
}

export function stampTaxComputeSave(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/stampTaxComputeSave',
    method: 'post',
    data:data,
  })
}
export function queryPageM(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/queryPage',
    method: 'post',
    data:data,
  })
}
export function getDetail(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/getDetail',
    method: 'post',
    data:data,
  })
}
export function commitAuditM(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/commitAudit',
    method: 'post',
    data:data,
  })
}
export function recall(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/recall',
    method: 'post',
    data:data,
  })
}
export function audit(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/audit',
    method: 'post',
    data:data,
  })
}
export function voucherList(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/voucherList',
    method: 'post',
    data:data,
  })
}
export function batchUpdateStampTaxItem(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/batchUpdateStampTaxItem',
    method: 'post',
    data:data,
  })
}
export function businessTypeList(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/businessTypeList',
    method: 'post',
    data:data,
  })
}
export function batchUpdateBusinessTypeM(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/batchUpdateBusinessType',
    method: 'post',
    data:data,
  })
}
export function updateBusinessType(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/updateBusinessType',
    method: 'post',
    data:data,
  })
}
export function queryListLI(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/queryList',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxInvoiceD(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/queryList',
    method: 'post',
    data:data,
  })
}
export function queryPageadsMatHyxtStampTaxComputeVoucherD(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeVoucherD/queryPage',
    method: 'post',
    data:data,
    params:data,
  })
}
export function stampTaxComputeBillExport(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/way1/stampTaxComputeBillExport',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function applyInvoiceExportDetail(data){
  return request({
    url: '/adsMatHyxtInvoiceD/applyInvoiceExportDetail',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function dataExportContractD(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/dataExport',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function dataExportTaxInvoiceD(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/dataExport',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function adsMatHyxtStampTaxComputeVoucherD(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeVoucherD/dataExport',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function getRiskPreventList1(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/warningRule1',
    method: 'post',
    data,
  })
}
export function getRiskPreventList2(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/warningRule2',
    method: 'post',
    data,
  })
}
export function getWarningRules(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/warningRule',
    method: 'post',
    data,
  })
}
export function batchDelete(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/batchDelete',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxContractDbatchDelete(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/batchDelete',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxZhptInvoiceD(data){
  return request({
    url: '/adsMatHyxtStampTaxZhptInvoiceD/queryPage',
    method: 'post',
    data:data,
    params:data,
  })
}
export function downloadTemplateInvoiceD(data){
  return request({
    url: '/adsMatHyxtStampTaxZhptInvoiceD/downloadTemplate',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function adsMatHyxtStampTaxZhptInvoiceDimportData(data){
  return request({
    url: '/adsMatHyxtStampTaxZhptInvoiceD/importData',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxZhptInvoiceDbatchDelete(data){
  return request({
    url: '/adsMatHyxtStampTaxZhptInvoiceD/batchDelete',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxZhptInvoiceDlis(data){
  return request({
    url: '/adsMatHyxtStampTaxZhptInvoiceD/item/list',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxZhptInvoiceDdownloadTemplate(data){
  return request({
    url: '/adsMatHyxtStampTaxZhptInvoiceD/item/downloadTemplate',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function adsMatHyxtStampTaxbatchDelete(data){
  return request({
    url: '/adsMatHyxtStampTaxZhptInvoiceD/item/batchDelete',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxZhptInvoiceDDimportData(data){
  return request({
    url: '/adsMatHyxtStampTaxZhptInvoiceD/item/importData',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxZhptInvoidataExport(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/dataExport',
    method: 'post',
    data:data,
    responseType: 'blob',
  })
}
export function warningType1(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/warningType1',
    method: 'post',
    data:data,
  })
}
export function warningType2(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/warningType2',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxWarningDwarningList(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/warningList',
    method: 'post',
    data:data,
  })
}
export function stampTaxC(data){
  return request({
    url: '/home/stampTax/count',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxContractD(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/contractImportCheck',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxContractDcontractImport(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/contractImport',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxContinvoiceImportCheck(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/invoiceImportCheck',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxContinvinvoiceImport(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/invoiceImport',
    method: 'post',
    data:data,
  })
}

// 清除印花税模块合同预警
export function clearStampTaxContractWarning(data){
  return request({
    url: '/adsMatHyxtStampTaxContractD/clearWarning',
    method: 'post',
    data:data,
  })
}

// 清除印花税模块发票预警
export function clearStampTaxInvoiceWarning(data){
  return request({
    url: '/adsMatHyxtStampTaxInvoiceD/clearWarning',
    method: 'post',
    data:data,
  })
}

export function adsMatHyxtStampTaxComputeDchange(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/change',
    method: 'post',
    data:data,
  })
}
export function adsMatHyxtStampTaxqueryWarningList(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/queryWarningList',
    method: 'post',
    data:data,
  })
}


export function queryWarningListNew(data){
  return request({
    url: '/adsMatHyxtStampTaxWarningD/queryWarningListNew',
    method: 'post',
    data:data,
  })
}

export function getTaxCategoryList(data){
  return request({
    url: '/adsMatHyxtStampTaxComputeD/stampTaxStatiss',
    method: 'post',
    data:data,
  })
}


